@@ -6,7 +6,11 @@ from functools import partial, partialmethod
 from optparse import OptionParser
 
 from django.urls import resolve
-from django_fsm import FSMField, TransitionNotAllowed, get_available_user_FIELD_transitions
+from django_fsm import (
+    FSMField,
+    TransitionNotAllowed,
+    get_available_user_FIELD_transitions,
+)
 from rest_framework import status
 from rest_framework.decorators import action
 from rest_framework.request import Request
@@ -105,13 +109,15 @@ class FSMViewSetMixin(metaclass=FSMViewSetMixinMetaclass):
         obj = self.get_object()
         serializer_class = self.get_serializer_class()
 
+        serializer_context = self.get_serializer_context()
+
         if request.method == "GET":
             return Response(
-                serializer_class(instance=obj, context={"request": request}).data
+                serializer_class(instance=obj, context=serializer_context).data
             )
 
         serializer = serializer_class(
-            instance=obj, data=request.data, partial=True, context={"request": request}
+            instance=obj, data=request.data, partial=True, context=serializer_context
         )
         if serializer.is_valid():
             if len(serializer.validated_data) > 0:
@@ -127,7 +133,7 @@ class FSMViewSetMixin(metaclass=FSMViewSetMixinMetaclass):
             getattr(obj, action)()
             obj.save()
 
-            serializer = serializer_class(instance=obj, context={"request": request})
+            serializer = serializer_class(instance=obj, context=serializer_context)
             return Response(serializer.data)
 
         return Response(errors, status=status.HTTP_412_PRECONDITION_FAILED)
